Class: Google::Apis::StoragetransferV1::LoggingConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/storagetransfer_v1/classes.rb,
lib/google/apis/storagetransfer_v1/representations.rb,
lib/google/apis/storagetransfer_v1/representations.rb

Overview

Specifies the logging behavior for transfer operations. Logs can be sent to Cloud Logging for all transfer types. See Read transfer logs for details.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LoggingConfig

Returns a new instance of LoggingConfig.



791
792
793
# File 'lib/google/apis/storagetransfer_v1/classes.rb', line 791

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#enable_onprem_gcs_transfer_logsBoolean Also known as: enable_onprem_gcs_transfer_logs?

For PosixFilesystem transfers, enables file system transfer logs instead of, or in addition to, Cloud Logging. This option ignores [LoggableAction] and [ LoggableActionState]. If these are set, Cloud Logging will also be enabled for this transfer. Corresponds to the JSON property enableOnpremGcsTransferLogs

Returns:

  • (Boolean)


778
779
780
# File 'lib/google/apis/storagetransfer_v1/classes.rb', line 778

def enable_onprem_gcs_transfer_logs
  @enable_onprem_gcs_transfer_logs
end

#log_action_statesArray<String>

States in which log_actions are logged. If empty, no logs are generated. Corresponds to the JSON property logActionStates

Returns:

  • (Array<String>)


784
785
786
# File 'lib/google/apis/storagetransfer_v1/classes.rb', line 784

def log_action_states
  @log_action_states
end

#log_actionsArray<String>

Specifies the actions to be logged. If empty, no logs are generated. Corresponds to the JSON property logActions

Returns:

  • (Array<String>)


789
790
791
# File 'lib/google/apis/storagetransfer_v1/classes.rb', line 789

def log_actions
  @log_actions
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



796
797
798
799
800
# File 'lib/google/apis/storagetransfer_v1/classes.rb', line 796

def update!(**args)
  @enable_onprem_gcs_transfer_logs = args[:enable_onprem_gcs_transfer_logs] if args.key?(:enable_onprem_gcs_transfer_logs)
  @log_action_states = args[:log_action_states] if args.key?(:log_action_states)
  @log_actions = args[:log_actions] if args.key?(:log_actions)
end