Class: Google::Apis::StoragetransferV1::S3CompatibleMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/storagetransfer_v1/classes.rb,
lib/google/apis/storagetransfer_v1/representations.rb,
lib/google/apis/storagetransfer_v1/representations.rb

Overview

S3CompatibleMetadata contains the metadata fields that apply to the basic types of S3-compatible data providers.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ S3CompatibleMetadata

Returns a new instance of S3CompatibleMetadata.



1274
1275
1276
# File 'lib/google/apis/storagetransfer_v1/classes.rb', line 1274

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#auth_methodString

Specifies the authentication and authorization method used by the storage service. When not specified, Transfer Service will attempt to determine right auth method to use. Corresponds to the JSON property authMethod

Returns:

  • (String)


1253
1254
1255
# File 'lib/google/apis/storagetransfer_v1/classes.rb', line 1253

def auth_method
  @auth_method
end

#list_apiString

The Listing API to use for discovering objects. When not specified, Transfer Service will attempt to determine the right API to use. Corresponds to the JSON property listApi

Returns:

  • (String)


1259
1260
1261
# File 'lib/google/apis/storagetransfer_v1/classes.rb', line 1259

def list_api
  @list_api
end

#protocolString

Specifies the network protocol of the agent. When not specified, the default value of NetworkProtocol NETWORK_PROTOCOL_HTTPS is used. Corresponds to the JSON property protocol

Returns:

  • (String)


1265
1266
1267
# File 'lib/google/apis/storagetransfer_v1/classes.rb', line 1265

def protocol
  @protocol
end

#request_modelString

Specifies the API request model used to call the storage service. When not specified, the default value of RequestModel REQUEST_MODEL_VIRTUAL_HOSTED_STYLE is used. Corresponds to the JSON property requestModel

Returns:

  • (String)


1272
1273
1274
# File 'lib/google/apis/storagetransfer_v1/classes.rb', line 1272

def request_model
  @request_model
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1279
1280
1281
1282
1283
1284
# File 'lib/google/apis/storagetransfer_v1/classes.rb', line 1279

def update!(**args)
  @auth_method = args[:auth_method] if args.key?(:auth_method)
  @list_api = args[:list_api] if args.key?(:list_api)
  @protocol = args[:protocol] if args.key?(:protocol)
  @request_model = args[:request_model] if args.key?(:request_model)
end