Class: Google::Apis::StoragetransferV1::TransferCounters

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/storagetransfer_v1/classes.rb,
lib/google/apis/storagetransfer_v1/representations.rb,
lib/google/apis/storagetransfer_v1/representations.rb

Overview

A collection of counters that report the progress of a transfer operation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TransferCounters

Returns a new instance of TransferCounters.



1568
1569
1570
# File 'lib/google/apis/storagetransfer_v1/classes.rb', line 1568

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bytes_copied_to_sinkFixnum

Bytes that are copied to the data sink. Corresponds to the JSON property bytesCopiedToSink

Returns:

  • (Fixnum)


1440
1441
1442
# File 'lib/google/apis/storagetransfer_v1/classes.rb', line 1440

def bytes_copied_to_sink
  @bytes_copied_to_sink
end

#bytes_deleted_from_sinkFixnum

Bytes that are deleted from the data sink. Corresponds to the JSON property bytesDeletedFromSink

Returns:

  • (Fixnum)


1445
1446
1447
# File 'lib/google/apis/storagetransfer_v1/classes.rb', line 1445

def bytes_deleted_from_sink
  @bytes_deleted_from_sink
end

#bytes_deleted_from_sourceFixnum

Bytes that are deleted from the data source. Corresponds to the JSON property bytesDeletedFromSource

Returns:

  • (Fixnum)


1450
1451
1452
# File 'lib/google/apis/storagetransfer_v1/classes.rb', line 1450

def bytes_deleted_from_source
  @bytes_deleted_from_source
end

#bytes_failed_to_delete_from_sinkFixnum

Bytes that failed to be deleted from the data sink. Corresponds to the JSON property bytesFailedToDeleteFromSink

Returns:

  • (Fixnum)


1455
1456
1457
# File 'lib/google/apis/storagetransfer_v1/classes.rb', line 1455

def bytes_failed_to_delete_from_sink
  @bytes_failed_to_delete_from_sink
end

#bytes_found_from_sourceFixnum

Bytes found in the data source that are scheduled to be transferred, excluding any that are filtered based on object conditions or skipped due to sync. Corresponds to the JSON property bytesFoundFromSource

Returns:

  • (Fixnum)


1461
1462
1463
# File 'lib/google/apis/storagetransfer_v1/classes.rb', line 1461

def bytes_found_from_source
  @bytes_found_from_source
end

#bytes_found_only_from_sinkFixnum

Bytes found only in the data sink that are scheduled to be deleted. Corresponds to the JSON property bytesFoundOnlyFromSink

Returns:

  • (Fixnum)


1466
1467
1468
# File 'lib/google/apis/storagetransfer_v1/classes.rb', line 1466

def bytes_found_only_from_sink
  @bytes_found_only_from_sink
end

#bytes_from_source_failedFixnum

Bytes in the data source that failed to be transferred or that failed to be deleted after being transferred. Corresponds to the JSON property bytesFromSourceFailed

Returns:

  • (Fixnum)


1472
1473
1474
# File 'lib/google/apis/storagetransfer_v1/classes.rb', line 1472

def bytes_from_source_failed
  @bytes_from_source_failed
end

#bytes_from_source_skipped_by_syncFixnum

Bytes in the data source that are not transferred because they already exist in the data sink. Corresponds to the JSON property bytesFromSourceSkippedBySync

Returns:

  • (Fixnum)


1478
1479
1480
# File 'lib/google/apis/storagetransfer_v1/classes.rb', line 1478

def bytes_from_source_skipped_by_sync
  @bytes_from_source_skipped_by_sync
end

#directories_failed_to_list_from_sourceFixnum

For transfers involving PosixFilesystem only. Number of listing failures for each directory found at the source. Potential failures when listing a directory include permission failure or block failure. If listing a directory fails, no files in the directory are transferred. Corresponds to the JSON property directoriesFailedToListFromSource

Returns:

  • (Fixnum)


1486
1487
1488
# File 'lib/google/apis/storagetransfer_v1/classes.rb', line 1486

def directories_failed_to_list_from_source
  @directories_failed_to_list_from_source
end

#directories_found_from_sourceFixnum

For transfers involving PosixFilesystem only. Number of directories found while listing. For example, if the root directory of the transfer is base/ and there are two other directories, a/ and b/ under this directory, the count after listing base/, base/a/ and base/b/ is 3. Corresponds to the JSON property directoriesFoundFromSource

Returns:

  • (Fixnum)


1494
1495
1496
# File 'lib/google/apis/storagetransfer_v1/classes.rb', line 1494

def directories_found_from_source
  @directories_found_from_source
end

#directories_successfully_listed_from_sourceFixnum

For transfers involving PosixFilesystem only. Number of successful listings for each directory found at the source. Corresponds to the JSON property directoriesSuccessfullyListedFromSource

Returns:

  • (Fixnum)


1500
1501
1502
# File 'lib/google/apis/storagetransfer_v1/classes.rb', line 1500

def directories_successfully_listed_from_source
  @directories_successfully_listed_from_source
end

#intermediate_objects_cleaned_upFixnum

Number of successfully cleaned up intermediate objects. Corresponds to the JSON property intermediateObjectsCleanedUp

Returns:

  • (Fixnum)


1505
1506
1507
# File 'lib/google/apis/storagetransfer_v1/classes.rb', line 1505

def intermediate_objects_cleaned_up
  @intermediate_objects_cleaned_up
end

#intermediate_objects_failed_cleaned_upFixnum

Number of intermediate objects failed cleaned up. Corresponds to the JSON property intermediateObjectsFailedCleanedUp

Returns:

  • (Fixnum)


1510
1511
1512
# File 'lib/google/apis/storagetransfer_v1/classes.rb', line 1510

def intermediate_objects_failed_cleaned_up
  @intermediate_objects_failed_cleaned_up
end

#objects_copied_to_sinkFixnum

Objects that are copied to the data sink. Corresponds to the JSON property objectsCopiedToSink

Returns:

  • (Fixnum)


1515
1516
1517
# File 'lib/google/apis/storagetransfer_v1/classes.rb', line 1515

def objects_copied_to_sink
  @objects_copied_to_sink
end

#objects_deleted_from_sinkFixnum

Objects that are deleted from the data sink. Corresponds to the JSON property objectsDeletedFromSink

Returns:

  • (Fixnum)


1520
1521
1522
# File 'lib/google/apis/storagetransfer_v1/classes.rb', line 1520

def objects_deleted_from_sink
  @objects_deleted_from_sink
end

#objects_deleted_from_sourceFixnum

Objects that are deleted from the data source. Corresponds to the JSON property objectsDeletedFromSource

Returns:

  • (Fixnum)


1525
1526
1527
# File 'lib/google/apis/storagetransfer_v1/classes.rb', line 1525

def objects_deleted_from_source
  @objects_deleted_from_source
end

#objects_failed_to_delete_from_sinkFixnum

Objects that failed to be deleted from the data sink. Corresponds to the JSON property objectsFailedToDeleteFromSink

Returns:

  • (Fixnum)


1530
1531
1532
# File 'lib/google/apis/storagetransfer_v1/classes.rb', line 1530

def objects_failed_to_delete_from_sink
  @objects_failed_to_delete_from_sink
end

#objects_found_from_sourceFixnum

Objects found in the data source that are scheduled to be transferred, excluding any that are filtered based on object conditions or skipped due to sync. Corresponds to the JSON property objectsFoundFromSource

Returns:

  • (Fixnum)


1537
1538
1539
# File 'lib/google/apis/storagetransfer_v1/classes.rb', line 1537

def objects_found_from_source
  @objects_found_from_source
end

#objects_found_only_from_sinkFixnum

Objects found only in the data sink that are scheduled to be deleted. Corresponds to the JSON property objectsFoundOnlyFromSink

Returns:

  • (Fixnum)


1542
1543
1544
# File 'lib/google/apis/storagetransfer_v1/classes.rb', line 1542

def objects_found_only_from_sink
  @objects_found_only_from_sink
end

#objects_from_source_failedFixnum

Objects in the data source that failed to be transferred or that failed to be deleted after being transferred. Corresponds to the JSON property objectsFromSourceFailed

Returns:

  • (Fixnum)


1548
1549
1550
# File 'lib/google/apis/storagetransfer_v1/classes.rb', line 1548

def objects_from_source_failed
  @objects_from_source_failed
end

#objects_from_source_skipped_by_syncFixnum

Objects in the data source that are not transferred because they already exist in the data sink. Corresponds to the JSON property objectsFromSourceSkippedBySync

Returns:

  • (Fixnum)


1554
1555
1556
# File 'lib/google/apis/storagetransfer_v1/classes.rb', line 1554

def objects_from_source_skipped_by_sync
  @objects_from_source_skipped_by_sync
end

#unrestored_deep_archive_objects_skipped_countFixnum

Number of unrestored deep archive objects skipped. Corresponds to the JSON property unrestoredDeepArchiveObjectsSkippedCount

Returns:

  • (Fixnum)


1559
1560
1561
# File 'lib/google/apis/storagetransfer_v1/classes.rb', line 1559

def unrestored_deep_archive_objects_skipped_count
  @unrestored_deep_archive_objects_skipped_count
end

#unsupported_s3_glacier_objects_skipped_countFixnum

Number of glacier objects skipped, glacier objects are unsupported by default regardless of the restore status. Allowlist the project to copy glacier objects if needed. Corresponds to the JSON property unsupportedS3GlacierObjectsSkippedCount

Returns:

  • (Fixnum)


1566
1567
1568
# File 'lib/google/apis/storagetransfer_v1/classes.rb', line 1566

def unsupported_s3_glacier_objects_skipped_count
  @unsupported_s3_glacier_objects_skipped_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1573
1574
1575
1576
1577
1578
1579
1580
1581
1582
1583
1584
1585
1586
1587
1588
1589
1590
1591
1592
1593
1594
1595
1596
1597
# File 'lib/google/apis/storagetransfer_v1/classes.rb', line 1573

def update!(**args)
  @bytes_copied_to_sink = args[:bytes_copied_to_sink] if args.key?(:bytes_copied_to_sink)
  @bytes_deleted_from_sink = args[:bytes_deleted_from_sink] if args.key?(:bytes_deleted_from_sink)
  @bytes_deleted_from_source = args[:bytes_deleted_from_source] if args.key?(:bytes_deleted_from_source)
  @bytes_failed_to_delete_from_sink = args[:bytes_failed_to_delete_from_sink] if args.key?(:bytes_failed_to_delete_from_sink)
  @bytes_found_from_source = args[:bytes_found_from_source] if args.key?(:bytes_found_from_source)
  @bytes_found_only_from_sink = args[:bytes_found_only_from_sink] if args.key?(:bytes_found_only_from_sink)
  @bytes_from_source_failed = args[:bytes_from_source_failed] if args.key?(:bytes_from_source_failed)
  @bytes_from_source_skipped_by_sync = args[:bytes_from_source_skipped_by_sync] if args.key?(:bytes_from_source_skipped_by_sync)
  @directories_failed_to_list_from_source = args[:directories_failed_to_list_from_source] if args.key?(:directories_failed_to_list_from_source)
  @directories_found_from_source = args[:directories_found_from_source] if args.key?(:directories_found_from_source)
  @directories_successfully_listed_from_source = args[:directories_successfully_listed_from_source] if args.key?(:directories_successfully_listed_from_source)
  @intermediate_objects_cleaned_up = args[:intermediate_objects_cleaned_up] if args.key?(:intermediate_objects_cleaned_up)
  @intermediate_objects_failed_cleaned_up = args[:intermediate_objects_failed_cleaned_up] if args.key?(:intermediate_objects_failed_cleaned_up)
  @objects_copied_to_sink = args[:objects_copied_to_sink] if args.key?(:objects_copied_to_sink)
  @objects_deleted_from_sink = args[:objects_deleted_from_sink] if args.key?(:objects_deleted_from_sink)
  @objects_deleted_from_source = args[:objects_deleted_from_source] if args.key?(:objects_deleted_from_source)
  @objects_failed_to_delete_from_sink = args[:objects_failed_to_delete_from_sink] if args.key?(:objects_failed_to_delete_from_sink)
  @objects_found_from_source = args[:objects_found_from_source] if args.key?(:objects_found_from_source)
  @objects_found_only_from_sink = args[:objects_found_only_from_sink] if args.key?(:objects_found_only_from_sink)
  @objects_from_source_failed = args[:objects_from_source_failed] if args.key?(:objects_from_source_failed)
  @objects_from_source_skipped_by_sync = args[:objects_from_source_skipped_by_sync] if args.key?(:objects_from_source_skipped_by_sync)
  @unrestored_deep_archive_objects_skipped_count = args[:unrestored_deep_archive_objects_skipped_count] if args.key?(:unrestored_deep_archive_objects_skipped_count)
  @unsupported_s3_glacier_objects_skipped_count = args[:unsupported_s3_glacier_objects_skipped_count] if args.key?(:unsupported_s3_glacier_objects_skipped_count)
end