Class: Google::Apis::StoragetransferV1::UpdateTransferJobRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/storagetransfer_v1/classes.rb,
lib/google/apis/storagetransfer_v1/representations.rb,
lib/google/apis/storagetransfer_v1/representations.rb

Overview

Request passed to UpdateTransferJob.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UpdateTransferJobRequest

Returns a new instance of UpdateTransferJobRequest.



2072
2073
2074
# File 'lib/google/apis/storagetransfer_v1/classes.rb', line 2072

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#project_idString

Required. The ID of the Google Cloud project that owns the job. Corresponds to the JSON property projectId

Returns:

  • (String)


2054
2055
2056
# File 'lib/google/apis/storagetransfer_v1/classes.rb', line 2054

def project_id
  @project_id
end

#transfer_jobGoogle::Apis::StoragetransferV1::TransferJob

This resource represents the configuration of a transfer job that runs periodically. Corresponds to the JSON property transferJob



2060
2061
2062
# File 'lib/google/apis/storagetransfer_v1/classes.rb', line 2060

def transfer_job
  @transfer_job
end

#update_transfer_job_field_maskString

The field mask of the fields in transferJob that are to be updated in this request. Fields in transferJob that can be updated are: description, transfer_spec, notification_config, logging_config, and status. To update the transfer_spec of the job, a complete transfer specification must be provided. An incomplete specification missing any required fields is rejected with the error INVALID_ARGUMENT. Corresponds to the JSON property updateTransferJobFieldMask

Returns:

  • (String)


2070
2071
2072
# File 'lib/google/apis/storagetransfer_v1/classes.rb', line 2070

def update_transfer_job_field_mask
  @update_transfer_job_field_mask
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2077
2078
2079
2080
2081
# File 'lib/google/apis/storagetransfer_v1/classes.rb', line 2077

def update!(**args)
  @project_id = args[:project_id] if args.key?(:project_id)
  @transfer_job = args[:transfer_job] if args.key?(:transfer_job)
  @update_transfer_job_field_mask = args[:update_transfer_job_field_mask] if args.key?(:update_transfer_job_field_mask)
end