Class: Google::Apis::StoragetransferV1::Operation
- Inherits:
-
Object
- Object
- Google::Apis::StoragetransferV1::Operation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/storagetransfer_v1/classes.rb,
lib/google/apis/storagetransfer_v1/representations.rb,
lib/google/apis/storagetransfer_v1/representations.rb
Overview
This resource represents a long-running operation that is the result of a network API call.
Instance Attribute Summary collapse
-
#done ⇒ Boolean
(also: #done?)
If the value is
false, it means the operation is still in progress. -
#error ⇒ Google::Apis::StoragetransferV1::Status
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#metadata ⇒ Hash<String,Object>
Represents the transfer operation object.
-
#name ⇒ String
The server-assigned unique name.
-
#response ⇒ Hash<String,Object>
The normal, successful response of the operation.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Operation
constructor
A new instance of Operation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Operation
Returns a new instance of Operation.
1108 1109 1110 |
# File 'lib/google/apis/storagetransfer_v1/classes.rb', line 1108 def initialize(**args) update!(**args) end |
Instance Attribute Details
#done ⇒ Boolean Also known as: done?
If the value is false, it means the operation is still in progress. If true
, the operation is completed, and either error or response is available.
Corresponds to the JSON property done
1072 1073 1074 |
# File 'lib/google/apis/storagetransfer_v1/classes.rb', line 1072 def done @done end |
#error ⇒ Google::Apis::StoragetransferV1::Status
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property error
1083 1084 1085 |
# File 'lib/google/apis/storagetransfer_v1/classes.rb', line 1083 def error @error end |
#metadata ⇒ Hash<String,Object>
Represents the transfer operation object. To request a TransferOperation
object, use transferOperations.get.
Corresponds to the JSON property metadata
1089 1090 1091 |
# File 'lib/google/apis/storagetransfer_v1/classes.rb', line 1089 def @metadata end |
#name ⇒ String
The server-assigned unique name. The format of name is transferOperations/
some/unique/name.
Corresponds to the JSON property name
1095 1096 1097 |
# File 'lib/google/apis/storagetransfer_v1/classes.rb', line 1095 def name @name end |
#response ⇒ Hash<String,Object>
The normal, successful response of the operation. If the original method
returns no data on success, such as Delete, the response is google.protobuf.
Empty. If the original method is standard Get/Create/Update, the
response should be the resource. For other methods, the response should have
the type XxxResponse, where Xxx is the original method name. For example,
if the original method name is TakeSnapshot(), the inferred response type is
TakeSnapshotResponse.
Corresponds to the JSON property response
1106 1107 1108 |
# File 'lib/google/apis/storagetransfer_v1/classes.rb', line 1106 def response @response end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1113 1114 1115 1116 1117 1118 1119 |
# File 'lib/google/apis/storagetransfer_v1/classes.rb', line 1113 def update!(**args) @done = args[:done] if args.key?(:done) @error = args[:error] if args.key?(:error) @metadata = args[:metadata] if args.key?(:metadata) @name = args[:name] if args.key?(:name) @response = args[:response] if args.key?(:response) end |