Class: Google::Apis::StoragetransferV1::Operation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/storagetransfer_v1/classes.rb,
lib/google/apis/storagetransfer_v1/representations.rb,
lib/google/apis/storagetransfer_v1/representations.rb

Overview

This resource represents a long-running operation that is the result of a network API call.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Operation

Returns a new instance of Operation.



1095
1096
1097
# File 'lib/google/apis/storagetransfer_v1/classes.rb', line 1095

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#doneBoolean Also known as: done?

If the value is false, it means the operation is still in progress. If true , the operation is completed, and either error or response is available. Corresponds to the JSON property done

Returns:

  • (Boolean)


1059
1060
1061
# File 'lib/google/apis/storagetransfer_v1/classes.rb', line 1059

def done
  @done
end

#errorGoogle::Apis::StoragetransferV1::Status

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property error



1070
1071
1072
# File 'lib/google/apis/storagetransfer_v1/classes.rb', line 1070

def error
  @error
end

#metadataHash<String,Object>

Represents the transfer operation object. To request a TransferOperation object, use transferOperations.get. Corresponds to the JSON property metadata

Returns:

  • (Hash<String,Object>)


1076
1077
1078
# File 'lib/google/apis/storagetransfer_v1/classes.rb', line 1076

def 
  @metadata
end

#nameString

The server-assigned unique name. The format of name is transferOperations/ some/unique/name. Corresponds to the JSON property name

Returns:

  • (String)


1082
1083
1084
# File 'lib/google/apis/storagetransfer_v1/classes.rb', line 1082

def name
  @name
end

#responseHash<String,Object>

The normal, successful response of the operation. If the original method returns no data on success, such as Delete, the response is google.protobuf. Empty. If the original method is standard Get/Create/Update, the response should be the resource. For other methods, the response should have the type XxxResponse, where Xxx is the original method name. For example, if the original method name is TakeSnapshot(), the inferred response type is TakeSnapshotResponse. Corresponds to the JSON property response

Returns:

  • (Hash<String,Object>)


1093
1094
1095
# File 'lib/google/apis/storagetransfer_v1/classes.rb', line 1093

def response
  @response
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1100
1101
1102
1103
1104
1105
1106
# File 'lib/google/apis/storagetransfer_v1/classes.rb', line 1100

def update!(**args)
  @done = args[:done] if args.key?(:done)
  @error = args[:error] if args.key?(:error)
  @metadata = args[:metadata] if args.key?(:metadata)
  @name = args[:name] if args.key?(:name)
  @response = args[:response] if args.key?(:response)
end