Class: Google::Apis::StoragetransferV1::S3CompatibleMetadata
- Inherits:
-
Object
- Object
- Google::Apis::StoragetransferV1::S3CompatibleMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/storagetransfer_v1/classes.rb,
lib/google/apis/storagetransfer_v1/representations.rb,
lib/google/apis/storagetransfer_v1/representations.rb
Overview
S3CompatibleMetadata contains the metadata fields that apply to the basic types of S3-compatible data providers.
Instance Attribute Summary collapse
-
#auth_method ⇒ String
Specifies the authentication and authorization method used by the storage service.
-
#list_api ⇒ String
The Listing API to use for discovering objects.
-
#protocol ⇒ String
Specifies the network protocol of the agent.
-
#request_model ⇒ String
Specifies the API request model used to call the storage service.
Instance Method Summary collapse
-
#initialize(**args) ⇒ S3CompatibleMetadata
constructor
A new instance of S3CompatibleMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ S3CompatibleMetadata
Returns a new instance of S3CompatibleMetadata.
1261 1262 1263 |
# File 'lib/google/apis/storagetransfer_v1/classes.rb', line 1261 def initialize(**args) update!(**args) end |
Instance Attribute Details
#auth_method ⇒ String
Specifies the authentication and authorization method used by the storage
service. When not specified, Transfer Service will attempt to determine right
auth method to use.
Corresponds to the JSON property authMethod
1240 1241 1242 |
# File 'lib/google/apis/storagetransfer_v1/classes.rb', line 1240 def auth_method @auth_method end |
#list_api ⇒ String
The Listing API to use for discovering objects. When not specified, Transfer
Service will attempt to determine the right API to use.
Corresponds to the JSON property listApi
1246 1247 1248 |
# File 'lib/google/apis/storagetransfer_v1/classes.rb', line 1246 def list_api @list_api end |
#protocol ⇒ String
Specifies the network protocol of the agent. When not specified, the default
value of NetworkProtocol NETWORK_PROTOCOL_HTTPS is used.
Corresponds to the JSON property protocol
1252 1253 1254 |
# File 'lib/google/apis/storagetransfer_v1/classes.rb', line 1252 def protocol @protocol end |
#request_model ⇒ String
Specifies the API request model used to call the storage service. When not
specified, the default value of RequestModel
REQUEST_MODEL_VIRTUAL_HOSTED_STYLE is used.
Corresponds to the JSON property requestModel
1259 1260 1261 |
# File 'lib/google/apis/storagetransfer_v1/classes.rb', line 1259 def request_model @request_model end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1266 1267 1268 1269 1270 1271 |
# File 'lib/google/apis/storagetransfer_v1/classes.rb', line 1266 def update!(**args) @auth_method = args[:auth_method] if args.key?(:auth_method) @list_api = args[:list_api] if args.key?(:list_api) @protocol = args[:protocol] if args.key?(:protocol) @request_model = args[:request_model] if args.key?(:request_model) end |