Class: Google::Apis::StoragetransferV1::Schedule
- Inherits:
-
Object
- Object
- Google::Apis::StoragetransferV1::Schedule
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/storagetransfer_v1/classes.rb,
lib/google/apis/storagetransfer_v1/representations.rb,
lib/google/apis/storagetransfer_v1/representations.rb
Overview
Transfers can be scheduled to recur or to run just once.
Instance Attribute Summary collapse
-
#end_time_of_day ⇒ Google::Apis::StoragetransferV1::TimeOfDay
Represents a time of day.
-
#repeat_interval ⇒ String
Interval between the start of each scheduled TransferOperation.
-
#schedule_end_date ⇒ Google::Apis::StoragetransferV1::Date
Represents a whole or partial calendar date, such as a birthday.
-
#schedule_start_date ⇒ Google::Apis::StoragetransferV1::Date
Represents a whole or partial calendar date, such as a birthday.
-
#start_time_of_day ⇒ Google::Apis::StoragetransferV1::TimeOfDay
Represents a time of day.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Schedule
constructor
A new instance of Schedule.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Schedule
Returns a new instance of Schedule.
1322 1323 1324 |
# File 'lib/google/apis/storagetransfer_v1/classes.rb', line 1322 def initialize(**args) update!(**args) end |
Instance Attribute Details
#end_time_of_day ⇒ Google::Apis::StoragetransferV1::TimeOfDay
Represents a time of day. The date and time zone are either not significant or
are specified elsewhere. An API may choose to allow leap seconds. Related
types are google.type.Date and google.protobuf.Timestamp.
Corresponds to the JSON property endTimeOfDay
1283 1284 1285 |
# File 'lib/google/apis/storagetransfer_v1/classes.rb', line 1283 def end_time_of_day @end_time_of_day end |
#repeat_interval ⇒ String
Interval between the start of each scheduled TransferOperation. If unspecified,
the default value is 24 hours. This value may not be less than 1 hour.
Corresponds to the JSON property repeatInterval
1289 1290 1291 |
# File 'lib/google/apis/storagetransfer_v1/classes.rb', line 1289 def repeat_interval @repeat_interval end |
#schedule_end_date ⇒ Google::Apis::StoragetransferV1::Date
Represents a whole or partial calendar date, such as a birthday. The time of
day and time zone are either specified elsewhere or are insignificant. The
date is relative to the Gregorian Calendar. This can represent one of the
following: * A full date, with non-zero year, month, and day values. * A month
and day, with a zero year (for example, an anniversary). * A year on its own,
with a zero month and a zero day. * A year and month, with a zero day (for
example, a credit card expiration date). Related types: * google.type.
TimeOfDay * google.type.DateTime * google.protobuf.Timestamp
Corresponds to the JSON property scheduleEndDate
1301 1302 1303 |
# File 'lib/google/apis/storagetransfer_v1/classes.rb', line 1301 def schedule_end_date @schedule_end_date end |
#schedule_start_date ⇒ Google::Apis::StoragetransferV1::Date
Represents a whole or partial calendar date, such as a birthday. The time of
day and time zone are either specified elsewhere or are insignificant. The
date is relative to the Gregorian Calendar. This can represent one of the
following: * A full date, with non-zero year, month, and day values. * A month
and day, with a zero year (for example, an anniversary). * A year on its own,
with a zero month and a zero day. * A year and month, with a zero day (for
example, a credit card expiration date). Related types: * google.type.
TimeOfDay * google.type.DateTime * google.protobuf.Timestamp
Corresponds to the JSON property scheduleStartDate
1313 1314 1315 |
# File 'lib/google/apis/storagetransfer_v1/classes.rb', line 1313 def schedule_start_date @schedule_start_date end |
#start_time_of_day ⇒ Google::Apis::StoragetransferV1::TimeOfDay
Represents a time of day. The date and time zone are either not significant or
are specified elsewhere. An API may choose to allow leap seconds. Related
types are google.type.Date and google.protobuf.Timestamp.
Corresponds to the JSON property startTimeOfDay
1320 1321 1322 |
# File 'lib/google/apis/storagetransfer_v1/classes.rb', line 1320 def start_time_of_day @start_time_of_day end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1327 1328 1329 1330 1331 1332 1333 |
# File 'lib/google/apis/storagetransfer_v1/classes.rb', line 1327 def update!(**args) @end_time_of_day = args[:end_time_of_day] if args.key?(:end_time_of_day) @repeat_interval = args[:repeat_interval] if args.key?(:repeat_interval) @schedule_end_date = args[:schedule_end_date] if args.key?(:schedule_end_date) @schedule_start_date = args[:schedule_start_date] if args.key?(:schedule_start_date) @start_time_of_day = args[:start_time_of_day] if args.key?(:start_time_of_day) end |