Class: Google::Apis::StoragetransferV1::TransferCounters
- Inherits:
-
Object
- Object
- Google::Apis::StoragetransferV1::TransferCounters
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/storagetransfer_v1/classes.rb,
lib/google/apis/storagetransfer_v1/representations.rb,
lib/google/apis/storagetransfer_v1/representations.rb
Overview
A collection of counters that report the progress of a transfer operation.
Instance Attribute Summary collapse
-
#bytes_copied_to_sink ⇒ Fixnum
Bytes that are copied to the data sink.
-
#bytes_deleted_from_sink ⇒ Fixnum
Bytes that are deleted from the data sink.
-
#bytes_deleted_from_source ⇒ Fixnum
Bytes that are deleted from the data source.
-
#bytes_failed_to_delete_from_sink ⇒ Fixnum
Bytes that failed to be deleted from the data sink.
-
#bytes_found_from_source ⇒ Fixnum
Bytes found in the data source that are scheduled to be transferred, excluding any that are filtered based on object conditions or skipped due to sync.
-
#bytes_found_only_from_sink ⇒ Fixnum
Bytes found only in the data sink that are scheduled to be deleted.
-
#bytes_from_source_failed ⇒ Fixnum
Bytes in the data source that failed to be transferred or that failed to be deleted after being transferred.
-
#bytes_from_source_skipped_by_sync ⇒ Fixnum
Bytes in the data source that are not transferred because they already exist in the data sink.
-
#directories_failed_to_list_from_source ⇒ Fixnum
For transfers involving PosixFilesystem only.
-
#directories_found_from_source ⇒ Fixnum
For transfers involving PosixFilesystem only.
-
#directories_successfully_listed_from_source ⇒ Fixnum
For transfers involving PosixFilesystem only.
-
#intermediate_objects_cleaned_up ⇒ Fixnum
Number of successfully cleaned up intermediate objects.
-
#intermediate_objects_failed_cleaned_up ⇒ Fixnum
Number of intermediate objects failed cleaned up.
-
#objects_copied_to_sink ⇒ Fixnum
Objects that are copied to the data sink.
-
#objects_deleted_from_sink ⇒ Fixnum
Objects that are deleted from the data sink.
-
#objects_deleted_from_source ⇒ Fixnum
Objects that are deleted from the data source.
-
#objects_failed_to_delete_from_sink ⇒ Fixnum
Objects that failed to be deleted from the data sink.
-
#objects_found_from_source ⇒ Fixnum
Objects found in the data source that are scheduled to be transferred, excluding any that are filtered based on object conditions or skipped due to sync.
-
#objects_found_only_from_sink ⇒ Fixnum
Objects found only in the data sink that are scheduled to be deleted.
-
#objects_from_source_failed ⇒ Fixnum
Objects in the data source that failed to be transferred or that failed to be deleted after being transferred.
-
#objects_from_source_skipped_by_sync ⇒ Fixnum
Objects in the data source that are not transferred because they already exist in the data sink.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TransferCounters
constructor
A new instance of TransferCounters.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TransferCounters
Returns a new instance of TransferCounters.
1543 1544 1545 |
# File 'lib/google/apis/storagetransfer_v1/classes.rb', line 1543 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bytes_copied_to_sink ⇒ Fixnum
Bytes that are copied to the data sink.
Corresponds to the JSON property bytesCopiedToSink
1427 1428 1429 |
# File 'lib/google/apis/storagetransfer_v1/classes.rb', line 1427 def bytes_copied_to_sink @bytes_copied_to_sink end |
#bytes_deleted_from_sink ⇒ Fixnum
Bytes that are deleted from the data sink.
Corresponds to the JSON property bytesDeletedFromSink
1432 1433 1434 |
# File 'lib/google/apis/storagetransfer_v1/classes.rb', line 1432 def bytes_deleted_from_sink @bytes_deleted_from_sink end |
#bytes_deleted_from_source ⇒ Fixnum
Bytes that are deleted from the data source.
Corresponds to the JSON property bytesDeletedFromSource
1437 1438 1439 |
# File 'lib/google/apis/storagetransfer_v1/classes.rb', line 1437 def bytes_deleted_from_source @bytes_deleted_from_source end |
#bytes_failed_to_delete_from_sink ⇒ Fixnum
Bytes that failed to be deleted from the data sink.
Corresponds to the JSON property bytesFailedToDeleteFromSink
1442 1443 1444 |
# File 'lib/google/apis/storagetransfer_v1/classes.rb', line 1442 def bytes_failed_to_delete_from_sink @bytes_failed_to_delete_from_sink end |
#bytes_found_from_source ⇒ Fixnum
Bytes found in the data source that are scheduled to be transferred, excluding
any that are filtered based on object conditions or skipped due to sync.
Corresponds to the JSON property bytesFoundFromSource
1448 1449 1450 |
# File 'lib/google/apis/storagetransfer_v1/classes.rb', line 1448 def bytes_found_from_source @bytes_found_from_source end |
#bytes_found_only_from_sink ⇒ Fixnum
Bytes found only in the data sink that are scheduled to be deleted.
Corresponds to the JSON property bytesFoundOnlyFromSink
1453 1454 1455 |
# File 'lib/google/apis/storagetransfer_v1/classes.rb', line 1453 def bytes_found_only_from_sink @bytes_found_only_from_sink end |
#bytes_from_source_failed ⇒ Fixnum
Bytes in the data source that failed to be transferred or that failed to be
deleted after being transferred.
Corresponds to the JSON property bytesFromSourceFailed
1459 1460 1461 |
# File 'lib/google/apis/storagetransfer_v1/classes.rb', line 1459 def bytes_from_source_failed @bytes_from_source_failed end |
#bytes_from_source_skipped_by_sync ⇒ Fixnum
Bytes in the data source that are not transferred because they already exist
in the data sink.
Corresponds to the JSON property bytesFromSourceSkippedBySync
1465 1466 1467 |
# File 'lib/google/apis/storagetransfer_v1/classes.rb', line 1465 def bytes_from_source_skipped_by_sync @bytes_from_source_skipped_by_sync end |
#directories_failed_to_list_from_source ⇒ Fixnum
For transfers involving PosixFilesystem only. Number of listing failures for
each directory found at the source. Potential failures when listing a
directory include permission failure or block failure. If listing a directory
fails, no files in the directory are transferred.
Corresponds to the JSON property directoriesFailedToListFromSource
1473 1474 1475 |
# File 'lib/google/apis/storagetransfer_v1/classes.rb', line 1473 def directories_failed_to_list_from_source @directories_failed_to_list_from_source end |
#directories_found_from_source ⇒ Fixnum
For transfers involving PosixFilesystem only. Number of directories found
while listing. For example, if the root directory of the transfer is base/
and there are two other directories, a/ and b/ under this directory, the
count after listing base/, base/a/ and base/b/ is 3.
Corresponds to the JSON property directoriesFoundFromSource
1481 1482 1483 |
# File 'lib/google/apis/storagetransfer_v1/classes.rb', line 1481 def directories_found_from_source @directories_found_from_source end |
#directories_successfully_listed_from_source ⇒ Fixnum
For transfers involving PosixFilesystem only. Number of successful listings
for each directory found at the source.
Corresponds to the JSON property directoriesSuccessfullyListedFromSource
1487 1488 1489 |
# File 'lib/google/apis/storagetransfer_v1/classes.rb', line 1487 def directories_successfully_listed_from_source @directories_successfully_listed_from_source end |
#intermediate_objects_cleaned_up ⇒ Fixnum
Number of successfully cleaned up intermediate objects.
Corresponds to the JSON property intermediateObjectsCleanedUp
1492 1493 1494 |
# File 'lib/google/apis/storagetransfer_v1/classes.rb', line 1492 def intermediate_objects_cleaned_up @intermediate_objects_cleaned_up end |
#intermediate_objects_failed_cleaned_up ⇒ Fixnum
Number of intermediate objects failed cleaned up.
Corresponds to the JSON property intermediateObjectsFailedCleanedUp
1497 1498 1499 |
# File 'lib/google/apis/storagetransfer_v1/classes.rb', line 1497 def intermediate_objects_failed_cleaned_up @intermediate_objects_failed_cleaned_up end |
#objects_copied_to_sink ⇒ Fixnum
Objects that are copied to the data sink.
Corresponds to the JSON property objectsCopiedToSink
1502 1503 1504 |
# File 'lib/google/apis/storagetransfer_v1/classes.rb', line 1502 def objects_copied_to_sink @objects_copied_to_sink end |
#objects_deleted_from_sink ⇒ Fixnum
Objects that are deleted from the data sink.
Corresponds to the JSON property objectsDeletedFromSink
1507 1508 1509 |
# File 'lib/google/apis/storagetransfer_v1/classes.rb', line 1507 def objects_deleted_from_sink @objects_deleted_from_sink end |
#objects_deleted_from_source ⇒ Fixnum
Objects that are deleted from the data source.
Corresponds to the JSON property objectsDeletedFromSource
1512 1513 1514 |
# File 'lib/google/apis/storagetransfer_v1/classes.rb', line 1512 def objects_deleted_from_source @objects_deleted_from_source end |
#objects_failed_to_delete_from_sink ⇒ Fixnum
Objects that failed to be deleted from the data sink.
Corresponds to the JSON property objectsFailedToDeleteFromSink
1517 1518 1519 |
# File 'lib/google/apis/storagetransfer_v1/classes.rb', line 1517 def objects_failed_to_delete_from_sink @objects_failed_to_delete_from_sink end |
#objects_found_from_source ⇒ Fixnum
Objects found in the data source that are scheduled to be transferred,
excluding any that are filtered based on object conditions or skipped due to
sync.
Corresponds to the JSON property objectsFoundFromSource
1524 1525 1526 |
# File 'lib/google/apis/storagetransfer_v1/classes.rb', line 1524 def objects_found_from_source @objects_found_from_source end |
#objects_found_only_from_sink ⇒ Fixnum
Objects found only in the data sink that are scheduled to be deleted.
Corresponds to the JSON property objectsFoundOnlyFromSink
1529 1530 1531 |
# File 'lib/google/apis/storagetransfer_v1/classes.rb', line 1529 def objects_found_only_from_sink @objects_found_only_from_sink end |
#objects_from_source_failed ⇒ Fixnum
Objects in the data source that failed to be transferred or that failed to be
deleted after being transferred.
Corresponds to the JSON property objectsFromSourceFailed
1535 1536 1537 |
# File 'lib/google/apis/storagetransfer_v1/classes.rb', line 1535 def objects_from_source_failed @objects_from_source_failed end |
#objects_from_source_skipped_by_sync ⇒ Fixnum
Objects in the data source that are not transferred because they already exist
in the data sink.
Corresponds to the JSON property objectsFromSourceSkippedBySync
1541 1542 1543 |
# File 'lib/google/apis/storagetransfer_v1/classes.rb', line 1541 def objects_from_source_skipped_by_sync @objects_from_source_skipped_by_sync end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1548 1549 1550 1551 1552 1553 1554 1555 1556 1557 1558 1559 1560 1561 1562 1563 1564 1565 1566 1567 1568 1569 1570 |
# File 'lib/google/apis/storagetransfer_v1/classes.rb', line 1548 def update!(**args) @bytes_copied_to_sink = args[:bytes_copied_to_sink] if args.key?(:bytes_copied_to_sink) @bytes_deleted_from_sink = args[:bytes_deleted_from_sink] if args.key?(:bytes_deleted_from_sink) @bytes_deleted_from_source = args[:bytes_deleted_from_source] if args.key?(:bytes_deleted_from_source) @bytes_failed_to_delete_from_sink = args[:bytes_failed_to_delete_from_sink] if args.key?(:bytes_failed_to_delete_from_sink) @bytes_found_from_source = args[:bytes_found_from_source] if args.key?(:bytes_found_from_source) @bytes_found_only_from_sink = args[:bytes_found_only_from_sink] if args.key?(:bytes_found_only_from_sink) @bytes_from_source_failed = args[:bytes_from_source_failed] if args.key?(:bytes_from_source_failed) @bytes_from_source_skipped_by_sync = args[:bytes_from_source_skipped_by_sync] if args.key?(:bytes_from_source_skipped_by_sync) @directories_failed_to_list_from_source = args[:directories_failed_to_list_from_source] if args.key?(:directories_failed_to_list_from_source) @directories_found_from_source = args[:directories_found_from_source] if args.key?(:directories_found_from_source) @directories_successfully_listed_from_source = args[:directories_successfully_listed_from_source] if args.key?(:directories_successfully_listed_from_source) @intermediate_objects_cleaned_up = args[:intermediate_objects_cleaned_up] if args.key?(:intermediate_objects_cleaned_up) @intermediate_objects_failed_cleaned_up = args[:intermediate_objects_failed_cleaned_up] if args.key?(:intermediate_objects_failed_cleaned_up) @objects_copied_to_sink = args[:objects_copied_to_sink] if args.key?(:objects_copied_to_sink) @objects_deleted_from_sink = args[:objects_deleted_from_sink] if args.key?(:objects_deleted_from_sink) @objects_deleted_from_source = args[:objects_deleted_from_source] if args.key?(:objects_deleted_from_source) @objects_failed_to_delete_from_sink = args[:objects_failed_to_delete_from_sink] if args.key?(:objects_failed_to_delete_from_sink) @objects_found_from_source = args[:objects_found_from_source] if args.key?(:objects_found_from_source) @objects_found_only_from_sink = args[:objects_found_only_from_sink] if args.key?(:objects_found_only_from_sink) @objects_from_source_failed = args[:objects_from_source_failed] if args.key?(:objects_from_source_failed) @objects_from_source_skipped_by_sync = args[:objects_from_source_skipped_by_sync] if args.key?(:objects_from_source_skipped_by_sync) end |