Class: Google::Apis::StoragetransferV1::TransferOperation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/storagetransfer_v1/classes.rb,
lib/google/apis/storagetransfer_v1/representations.rb,
lib/google/apis/storagetransfer_v1/representations.rb

Overview

A description of the execution of a transfer.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TransferOperation

Returns a new instance of TransferOperation.



1819
1820
1821
# File 'lib/google/apis/storagetransfer_v1/classes.rb', line 1819

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#countersGoogle::Apis::StoragetransferV1::TransferCounters

A collection of counters that report the progress of a transfer operation. Corresponds to the JSON property counters



1757
1758
1759
# File 'lib/google/apis/storagetransfer_v1/classes.rb', line 1757

def counters
  @counters
end

#end_timeString

End time of this transfer execution. Corresponds to the JSON property endTime

Returns:

  • (String)


1762
1763
1764
# File 'lib/google/apis/storagetransfer_v1/classes.rb', line 1762

def end_time
  @end_time
end

#error_breakdownsArray<Google::Apis::StoragetransferV1::ErrorSummary>

Summarizes errors encountered with sample error log entries. Corresponds to the JSON property errorBreakdowns



1767
1768
1769
# File 'lib/google/apis/storagetransfer_v1/classes.rb', line 1767

def error_breakdowns
  @error_breakdowns
end

#logging_configGoogle::Apis::StoragetransferV1::LoggingConfig

Specifies the logging behavior for transfer operations. Logs can be sent to Cloud Logging for all transfer types. See Read transfer logs for details. Corresponds to the JSON property loggingConfig



1774
1775
1776
# File 'lib/google/apis/storagetransfer_v1/classes.rb', line 1774

def logging_config
  @logging_config
end

#nameString

A globally unique ID assigned by the system. Corresponds to the JSON property name

Returns:

  • (String)


1779
1780
1781
# File 'lib/google/apis/storagetransfer_v1/classes.rb', line 1779

def name
  @name
end

#notification_configGoogle::Apis::StoragetransferV1::NotificationConfig

Specification to configure notifications published to Pub/Sub. Notifications are published to the customer-provided topic using the following PubsubMessage.attributes: * "eventType": one of the EventType values * " payloadFormat": one of the PayloadFormat values * "projectId": the project_id of the TransferOperation * "transferJobName": the transfer_job_name of the TransferOperation * "transferOperationName": the name of the TransferOperation The PubsubMessage.data contains a TransferOperation resource formatted according to the specified PayloadFormat . Corresponds to the JSON property notificationConfig



1792
1793
1794
# File 'lib/google/apis/storagetransfer_v1/classes.rb', line 1792

def notification_config
  @notification_config
end

#project_idString

The ID of the Google Cloud project that owns the operation. Corresponds to the JSON property projectId

Returns:

  • (String)


1797
1798
1799
# File 'lib/google/apis/storagetransfer_v1/classes.rb', line 1797

def project_id
  @project_id
end

#start_timeString

Start time of this transfer execution. Corresponds to the JSON property startTime

Returns:

  • (String)


1802
1803
1804
# File 'lib/google/apis/storagetransfer_v1/classes.rb', line 1802

def start_time
  @start_time
end

#statusString

Status of the transfer operation. Corresponds to the JSON property status

Returns:

  • (String)


1807
1808
1809
# File 'lib/google/apis/storagetransfer_v1/classes.rb', line 1807

def status
  @status
end

#transfer_job_nameString

The name of the transfer job that triggers this transfer operation. Corresponds to the JSON property transferJobName

Returns:

  • (String)


1812
1813
1814
# File 'lib/google/apis/storagetransfer_v1/classes.rb', line 1812

def transfer_job_name
  @transfer_job_name
end

#transfer_specGoogle::Apis::StoragetransferV1::TransferSpec

Configuration for running a transfer. Corresponds to the JSON property transferSpec



1817
1818
1819
# File 'lib/google/apis/storagetransfer_v1/classes.rb', line 1817

def transfer_spec
  @transfer_spec
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1824
1825
1826
1827
1828
1829
1830
1831
1832
1833
1834
1835
1836
# File 'lib/google/apis/storagetransfer_v1/classes.rb', line 1824

def update!(**args)
  @counters = args[:counters] if args.key?(:counters)
  @end_time = args[:end_time] if args.key?(:end_time)
  @error_breakdowns = args[:error_breakdowns] if args.key?(:error_breakdowns)
  @logging_config = args[:logging_config] if args.key?(:logging_config)
  @name = args[:name] if args.key?(:name)
  @notification_config = args[:notification_config] if args.key?(:notification_config)
  @project_id = args[:project_id] if args.key?(:project_id)
  @start_time = args[:start_time] if args.key?(:start_time)
  @status = args[:status] if args.key?(:status)
  @transfer_job_name = args[:transfer_job_name] if args.key?(:transfer_job_name)
  @transfer_spec = args[:transfer_spec] if args.key?(:transfer_spec)
end