Class: Google::Apis::StoragetransferV1::TransferOptions

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/storagetransfer_v1/classes.rb,
lib/google/apis/storagetransfer_v1/representations.rb,
lib/google/apis/storagetransfer_v1/representations.rb

Overview

TransferOptions define the actions to be performed on objects in a transfer.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TransferOptions

Returns a new instance of TransferOptions.



1878
1879
1880
# File 'lib/google/apis/storagetransfer_v1/classes.rb', line 1878

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#delete_objects_from_source_after_transferBoolean Also known as: delete_objects_from_source_after_transfer?

Whether objects should be deleted from the source after they are transferred to the sink. Note: This option and delete_objects_unique_in_sink are mutually exclusive. Corresponds to the JSON property deleteObjectsFromSourceAfterTransfer

Returns:

  • (Boolean)


1848
1849
1850
# File 'lib/google/apis/storagetransfer_v1/classes.rb', line 1848

def delete_objects_from_source_after_transfer
  @delete_objects_from_source_after_transfer
end

#delete_objects_unique_in_sinkBoolean Also known as: delete_objects_unique_in_sink?

Whether objects that exist only in the sink should be deleted. Note: This option and delete_objects_from_source_after_transfer are mutually exclusive. Corresponds to the JSON property deleteObjectsUniqueInSink

Returns:

  • (Boolean)


1855
1856
1857
# File 'lib/google/apis/storagetransfer_v1/classes.rb', line 1855

def delete_objects_unique_in_sink
  @delete_objects_unique_in_sink
end

#metadata_optionsGoogle::Apis::StoragetransferV1::MetadataOptions

Specifies the metadata options for running a transfer. Corresponds to the JSON property metadataOptions



1861
1862
1863
# File 'lib/google/apis/storagetransfer_v1/classes.rb', line 1861

def 
  @metadata_options
end

#overwrite_objects_already_existing_in_sinkBoolean Also known as: overwrite_objects_already_existing_in_sink?

When to overwrite objects that already exist in the sink. The default is that only objects that are different from the source are overwritten. If true, all objects in the sink whose name matches an object in the source are overwritten with the source object. Corresponds to the JSON property overwriteObjectsAlreadyExistingInSink

Returns:

  • (Boolean)


1869
1870
1871
# File 'lib/google/apis/storagetransfer_v1/classes.rb', line 1869

def overwrite_objects_already_existing_in_sink
  @overwrite_objects_already_existing_in_sink
end

#overwrite_whenString

When to overwrite objects that already exist in the sink. If not set, overwrite behavior is determined by overwrite_objects_already_existing_in_sink. Corresponds to the JSON property overwriteWhen

Returns:

  • (String)


1876
1877
1878
# File 'lib/google/apis/storagetransfer_v1/classes.rb', line 1876

def overwrite_when
  @overwrite_when
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1883
1884
1885
1886
1887
1888
1889
# File 'lib/google/apis/storagetransfer_v1/classes.rb', line 1883

def update!(**args)
  @delete_objects_from_source_after_transfer = args[:delete_objects_from_source_after_transfer] if args.key?(:delete_objects_from_source_after_transfer)
  @delete_objects_unique_in_sink = args[:delete_objects_unique_in_sink] if args.key?(:delete_objects_unique_in_sink)
  @metadata_options = args[:metadata_options] if args.key?(:metadata_options)
  @overwrite_objects_already_existing_in_sink = args[:overwrite_objects_already_existing_in_sink] if args.key?(:overwrite_objects_already_existing_in_sink)
  @overwrite_when = args[:overwrite_when] if args.key?(:overwrite_when)
end