Class: Google::Apis::StoragetransferV1::TransferSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/storagetransfer_v1/classes.rb,
lib/google/apis/storagetransfer_v1/representations.rb,
lib/google/apis/storagetransfer_v1/representations.rb

Overview

Configuration for running a transfer.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TransferSpec

Returns a new instance of TransferSpec.



2009
2010
2011
# File 'lib/google/apis/storagetransfer_v1/classes.rb', line 2009

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#aws_s3_compatible_data_sourceGoogle::Apis::StoragetransferV1::AwsS3CompatibleData

An AwsS3CompatibleData resource. Corresponds to the JSON property awsS3CompatibleDataSource



1885
1886
1887
# File 'lib/google/apis/storagetransfer_v1/classes.rb', line 1885

def aws_s3_compatible_data_source
  @aws_s3_compatible_data_source
end

#aws_s3_data_sourceGoogle::Apis::StoragetransferV1::AwsS3Data

An AwsS3Data resource can be a data source, but not a data sink. In an AwsS3Data resource, an object's name is the S3 object's key name. Corresponds to the JSON property awsS3DataSource



1891
1892
1893
# File 'lib/google/apis/storagetransfer_v1/classes.rb', line 1891

def aws_s3_data_source
  @aws_s3_data_source
end

#azure_blob_storage_data_sourceGoogle::Apis::StoragetransferV1::AzureBlobStorageData

An AzureBlobStorageData resource can be a data source, but not a data sink. An AzureBlobStorageData resource represents one Azure container. The storage account determines the Azure endpoint. In an AzureBlobStorageData resource, a blobs's name is the Azure Blob Storage blob's key name. Corresponds to the JSON property azureBlobStorageDataSource



1902
1903
1904
# File 'lib/google/apis/storagetransfer_v1/classes.rb', line 1902

def azure_blob_storage_data_source
  @azure_blob_storage_data_source
end

#gcs_data_sinkGoogle::Apis::StoragetransferV1::GcsData

In a GcsData resource, an object's name is the Cloud Storage object's name and its "last modification time" refers to the object's updated property of Cloud Storage objects, which changes when the content or the metadata of the object is updated. Corresponds to the JSON property gcsDataSink



1910
1911
1912
# File 'lib/google/apis/storagetransfer_v1/classes.rb', line 1910

def gcs_data_sink
  @gcs_data_sink
end

#gcs_data_sourceGoogle::Apis::StoragetransferV1::GcsData

In a GcsData resource, an object's name is the Cloud Storage object's name and its "last modification time" refers to the object's updated property of Cloud Storage objects, which changes when the content or the metadata of the object is updated. Corresponds to the JSON property gcsDataSource



1918
1919
1920
# File 'lib/google/apis/storagetransfer_v1/classes.rb', line 1918

def gcs_data_source
  @gcs_data_source
end

#gcs_intermediate_data_locationGoogle::Apis::StoragetransferV1::GcsData

In a GcsData resource, an object's name is the Cloud Storage object's name and its "last modification time" refers to the object's updated property of Cloud Storage objects, which changes when the content or the metadata of the object is updated. Corresponds to the JSON property gcsIntermediateDataLocation



1926
1927
1928
# File 'lib/google/apis/storagetransfer_v1/classes.rb', line 1926

def gcs_intermediate_data_location
  @gcs_intermediate_data_location
end

#hdfs_data_sourceGoogle::Apis::StoragetransferV1::HdfsData

An HdfsData resource specifies a path within an HDFS entity (e.g. a cluster). All cluster-specific settings, such as namenodes and ports, are configured on the transfer agents servicing requests, so HdfsData only contains the root path to the data in our transfer. Corresponds to the JSON property hdfsDataSource



1934
1935
1936
# File 'lib/google/apis/storagetransfer_v1/classes.rb', line 1934

def hdfs_data_source
  @hdfs_data_source
end

#http_data_sourceGoogle::Apis::StoragetransferV1::HttpData

An HttpData resource specifies a list of objects on the web to be transferred over HTTP. The information of the objects to be transferred is contained in a file referenced by a URL. The first line in the file must be "TsvHttpData-1.0" , which specifies the format of the file. Subsequent lines specify the information of the list of objects, one object per list entry. Each entry has the following tab-delimited fields: * HTTP URL — The location of the object. * Length — The size of the object in bytes. * MD5 — The base64- encoded MD5 hash of the object. For an example of a valid TSV file, see Transferring data from URLs. When transferring data based on a URL list, keep the following in mind: * When an object located at http(s)://hostname:port/ is transferred to a data sink, the name of the object at the data sink is /. * If the specified size of an object does not match the actual size of the object fetched, the object is not transferred. * If the specified MD5 does not match the MD5 computed from the transferred bytes, the object transfer fails. * Ensure that each URL you specify is publicly accessible. For example, in Cloud Storage you can share an object publicly and get a link to it. * Storage Transfer Service obeys robots. txt rules and requires the source HTTP server to support Range requests and to return a Content-Length header in each response. * ObjectConditions have no effect when filtering objects to transfer. Corresponds to the JSON property httpDataSource



1959
1960
1961
# File 'lib/google/apis/storagetransfer_v1/classes.rb', line 1959

def http_data_source
  @http_data_source
end

#object_conditionsGoogle::Apis::StoragetransferV1::ObjectConditions

Conditions that determine which objects are transferred. Applies only to Cloud Data Sources such as S3, Azure, and Cloud Storage. The "last modification time" refers to the time of the last change to the object's content or metadata — specifically, this is the updated property of Cloud Storage objects, the LastModified field of S3 objects, and the Last-Modified header of Azure blobs. For S3 objects, the LastModified value is the time the object begins uploading. If the object meets your "last modification time" criteria, but has not finished uploading, the object is not transferred. See Transfer from Amazon S3 to Cloud Storage for more information. Transfers with a PosixFilesystem source or destination don't support ObjectConditions. Corresponds to the JSON property objectConditions



1975
1976
1977
# File 'lib/google/apis/storagetransfer_v1/classes.rb', line 1975

def object_conditions
  @object_conditions
end

#posix_data_sinkGoogle::Apis::StoragetransferV1::PosixFilesystem

A POSIX filesystem resource. Corresponds to the JSON property posixDataSink



1980
1981
1982
# File 'lib/google/apis/storagetransfer_v1/classes.rb', line 1980

def posix_data_sink
  @posix_data_sink
end

#posix_data_sourceGoogle::Apis::StoragetransferV1::PosixFilesystem

A POSIX filesystem resource. Corresponds to the JSON property posixDataSource



1985
1986
1987
# File 'lib/google/apis/storagetransfer_v1/classes.rb', line 1985

def posix_data_source
  @posix_data_source
end

#sink_agent_pool_nameString

Specifies the agent pool name associated with the posix data sink. When unspecified, the default name is used. Corresponds to the JSON property sinkAgentPoolName

Returns:

  • (String)


1991
1992
1993
# File 'lib/google/apis/storagetransfer_v1/classes.rb', line 1991

def sink_agent_pool_name
  @sink_agent_pool_name
end

#source_agent_pool_nameString

Specifies the agent pool name associated with the posix data source. When unspecified, the default name is used. Corresponds to the JSON property sourceAgentPoolName

Returns:

  • (String)


1997
1998
1999
# File 'lib/google/apis/storagetransfer_v1/classes.rb', line 1997

def source_agent_pool_name
  @source_agent_pool_name
end

#transfer_manifestGoogle::Apis::StoragetransferV1::TransferManifest

Specifies where the manifest is located. Corresponds to the JSON property transferManifest



2002
2003
2004
# File 'lib/google/apis/storagetransfer_v1/classes.rb', line 2002

def transfer_manifest
  @transfer_manifest
end

#transfer_optionsGoogle::Apis::StoragetransferV1::TransferOptions

TransferOptions define the actions to be performed on objects in a transfer. Corresponds to the JSON property transferOptions



2007
2008
2009
# File 'lib/google/apis/storagetransfer_v1/classes.rb', line 2007

def transfer_options
  @transfer_options
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2014
2015
2016
2017
2018
2019
2020
2021
2022
2023
2024
2025
2026
2027
2028
2029
2030
# File 'lib/google/apis/storagetransfer_v1/classes.rb', line 2014

def update!(**args)
  @aws_s3_compatible_data_source = args[:aws_s3_compatible_data_source] if args.key?(:aws_s3_compatible_data_source)
  @aws_s3_data_source = args[:aws_s3_data_source] if args.key?(:aws_s3_data_source)
  @azure_blob_storage_data_source = args[:azure_blob_storage_data_source] if args.key?(:azure_blob_storage_data_source)
  @gcs_data_sink = args[:gcs_data_sink] if args.key?(:gcs_data_sink)
  @gcs_data_source = args[:gcs_data_source] if args.key?(:gcs_data_source)
  @gcs_intermediate_data_location = args[:gcs_intermediate_data_location] if args.key?(:gcs_intermediate_data_location)
  @hdfs_data_source = args[:hdfs_data_source] if args.key?(:hdfs_data_source)
  @http_data_source = args[:http_data_source] if args.key?(:http_data_source)
  @object_conditions = args[:object_conditions] if args.key?(:object_conditions)
  @posix_data_sink = args[:posix_data_sink] if args.key?(:posix_data_sink)
  @posix_data_source = args[:posix_data_source] if args.key?(:posix_data_source)
  @sink_agent_pool_name = args[:sink_agent_pool_name] if args.key?(:sink_agent_pool_name)
  @source_agent_pool_name = args[:source_agent_pool_name] if args.key?(:source_agent_pool_name)
  @transfer_manifest = args[:transfer_manifest] if args.key?(:transfer_manifest)
  @transfer_options = args[:transfer_options] if args.key?(:transfer_options)
end